@@ -35,7 +35,11 @@ API_COMMANDS = [
     status,
 ]
 ALL_COMMANDS = API_COMMANDS + LOCAL_COMMANDS
+SERVER_CHECK_COMMAND_NAMES = [
+    command.name for command in API_COMMANDS if command.name not in ["status"]
+]
 VERSION = fidesctl.__version__
+APP = fidesctl.__name__
 
 
 @click.group(
@@ -77,28 +81,28 @@ def cli(ctx: click.Context, config_path: str, local: bool) -> None:
         config.cli.local_mode = True
 
     ctx.obj["CONFIG"] = config
+
+    # Run the help command if no subcommand is passed
     if not ctx.invoked_subcommand:
         click.echo(cli.get_help(ctx))
 
     # Check the server health and version if an API command is invoked
-    if (
-        ctx.invoked_subcommand in [command.name for command in API_COMMANDS]
-        and ctx.invoked_subcommand != "status"
-    ):
+
+    if ctx.invoked_subcommand in SERVER_CHECK_COMMAND_NAMES:
         check_server(VERSION, config.cli.server_url)
 
-    if ctx.invoked_subcommand != "init":  # init also handles this workflow
+    # init also handles this workflow
+    if ctx.invoked_subcommand != "init":
         check_and_update_analytics_config(ctx, config_path)
 
-        if (  # requires explicit opt-in
-            ctx.obj["CONFIG"].user.analytics_opt_out is False
-        ):
+        # Analytics requires explicit opt-in
+        if ctx.obj["CONFIG"].user.analytics_opt_out is False:
             ctx.meta["ANALYTICS_CLIENT"] = AnalyticsClient(
                 client_id=ctx.obj["CONFIG"].cli.analytics_id,
                 developer_mode=bool(getenv("FIDESCTL_TEST_MODE") == "True"),
                 os=system(),
-                product_name=fidesctl.__name__ + "-cli",
-                production_version=version(fidesctl.__name__),
+                product_name=APP + "-cli",
+                production_version=version(APP),
             )
 
 
