@@ -1,12 +1,13 @@
 """Contains all of the Utility-type CLI commands for Fidesctl."""
 import os
+from datetime import datetime, timezone
 
 import click
-from fideslog.sdk.python.utils import OPT_OUT_COPY
 import toml
+from fideslog.sdk.python.utils import OPT_OUT_COPY, OPT_OUT_PROMPT
 
 import fidesctl
-from fidesctl.cli.utils import check_server, with_analytics
+from fidesctl.cli.utils import check_server, send_init_analytics, with_analytics
 from fidesctl.core.utils import echo_green, echo_red
 
 
@@ -16,20 +17,19 @@ from fidesctl.core.utils import echo_green, echo_red
 def init(ctx: click.Context, fides_directory_location: str) -> None:
     """
     Initializes a Fidesctl instance, creating the default directory (`.fides/`) and
-    the configuration file (`fidesctl_config.toml`).
+    the configuration file (`fidesctl.toml`) if necessary.
 
     Additionally, requests the ability to respectfully collect anonymous usage data.
     """
 
-    # Constants
-    separate = lambda: print("-" * 10)
+    executed_at = datetime.now(timezone.utc)
+    separate = lambda: print("-" * 10, end=None)
     fides_dir_name = ".fides"
     fides_dir_path = f"{fides_directory_location}/{fides_dir_name}"
     config_file_name = "fidesctl.toml"
     config_path = f"{fides_dir_path}/{config_file_name}"
     config = ctx.obj["CONFIG"]
 
-    # List the values we want to include in the user-facing config
     included_values = {
         "api": {
             "database_user",
@@ -42,46 +42,54 @@ def init(ctx: click.Context, fides_directory_location: str) -> None:
             "log_destination",
             "log_serialization",
         },
-        "cli": {"server_url", "analytics_id"},
+        "cli": {"server_protocol", "server_host", "server_port", "analytics_id"},
         "user": {"analytics_opt_out"},
     }
 
     click.echo("Initializing Fidesctl...")
     separate()
 
-    # create the dir if it doesn't exist
+    # create the .fides dir if it doesn't exist
     if not os.path.exists(fides_dir_path):
         os.mkdir(fides_dir_path)
         echo_green(f"Created a '{fides_dir_path}' directory.")
     else:
         click.echo(f"Directory '{fides_dir_path}' already exists.")
+
     separate()
 
-    # create a config file if it doesn't exist
+    # create a fidesctl.toml config file if it doesn't exist
     if not os.path.isfile(config_path):
-        config_docs_url = "https://ethyca.github.io/fides/installation/configuration/"
-        config_message = f"""Created a config file at '{config_path}'. To learn more, see:
-            {config_docs_url}"""
-        config.user.analytics_opt_out = bool(input(OPT_OUT_COPY).lower() == "n")
+        # request explicit consent for analytics collection
+        click.echo(OPT_OUT_COPY, nl=False)
+        config.user.analytics_opt_out = bool(input(OPT_OUT_PROMPT).lower() == "n")
+
+        separate()
+
         with open(config_path, "w") as config_file:
             config_dict = config.dict(include=included_values)
             toml.dump(config_dict, config_file)
-        echo_green(config_message)
+
+        echo_green(f"Created a fidesctl config file: {config_path}")
+        click.echo("To learn more about configuring fidesctl, see:")
+        click.echo("\thttps://ethyca.github.io/fides/installation/configuration/")
 
     else:
-        click.echo(f"Configuration file already exists at '{config_path}'.")
+        click.echo(f"Configuration file already exists: {config_path}")
+
+    separate()
+    click.echo("For example policies and help getting started, see:")
+    click.echo("\thttps://ethyca.github.io/fides/guides/policies/")
     separate()
 
-    click.echo(
-        "For example policies to help get started, see: ethyca.github.io/fides/guides/policies/"
-    )
-    separate()
+    send_init_analytics(config.user.analytics_opt_out, config_path, executed_at)
 
     echo_green("Fidesctl initialization complete.")
 
 
 @click.command()
 @click.pass_context
+@with_analytics
 def status(ctx: click.Context) -> None:
     """
     Sends a request to the Fidesctl API healthcheck endpoint and prints the response.
@@ -90,9 +98,7 @@ def status(ctx: click.Context) -> None:
     cli_version = fidesctl.__version__
     server_url = config.cli.server_url
     click.echo("Getting server status...")
-    with_analytics(
-        ctx,
-        check_server,
+    check_server(
         cli_version=cli_version,
         server_url=server_url,
     )
@@ -100,6 +106,7 @@ def status(ctx: click.Context) -> None:
 
 @click.command()
 @click.pass_context
+@with_analytics
 def webserver(ctx: click.Context) -> None:
     """
     Starts the fidesctl API server using Uvicorn on port 8080.
@@ -110,4 +117,4 @@ def webserver(ctx: click.Context) -> None:
         echo_red('Packages not found, try: pip install "fidesctl[webserver]"')
         raise SystemExit
 
-    with_analytics(ctx, start_webserver)
+    start_webserver()
